@@ -3,11 +3,12 @@ import shutil
 import sys
 import tempfile
 from contextlib import contextmanager
+import shutil 
 
 from scrapy.utils.misc import load_object
 
 from scrapyd import Config
-from scrapyd.eggutils import activate_egg
+from scrapyd.eggutils import activate_egg , activate_scrapycfg
 
 
 @contextmanager
@@ -25,21 +26,29 @@ def project_environment(project):
         prefix = '%s-%s-' % (project, version)
         fd, eggpath = tempfile.mkstemp(prefix=prefix, suffix='.egg')
         lf = os.fdopen(fd, 'wb')
+        extrpath = os.path.dirname(eggpath) + '%s-%s' % (project, version)
+
         shutil.copyfileobj(eggfile, lf)
         lf.close()
         activate_egg(eggpath)
+        activate_scrapycfg(eggpath,extrpath)
     else:
         eggpath = None
     try:
         assert 'scrapy.conf' not in sys.modules, "Scrapy settings already loaded"
         yield
     finally:
+        # pass
         if eggpath:
             os.remove(eggpath)
+        if extrpath:
+            shutil.rmtree(extrpath)
+
 
 
 def main():
-    project = os.environ['SCRAPY_PROJECT']
+    # project = os.environ['SCRAPY_PROJECT']
+    project = "de-xccnews"
     with project_environment(project):
         from scrapy.cmdline import execute
         execute()
